;;; Directory Local Variables            -*- no-byte-compile: t -*-
;;; For more information see (info "(emacs) Directory Variables")

((nil . ((indent-tabs-mode . nil)))
 (emacs-lisp-mode . ((package-lint-main-file . "mastodon.el"))))
